@@ -17,6 +17,7 @@ from solid.test.ExpandedTestCase import DiffOutput
 
 scad_test_case_templates = [
     {'name': 'polygon', 'class': 'polygon' , 'kwargs': {'paths': [[0, 1, 2]]}, 'expected': '\n\npolygon(paths = [[0, 1, 2]], points = [[0, 0], [1, 0], [0, 1]]);', 'args': {'points': [[0, 0, 0], [1, 0, 0], [0, 1, 0]]}, },
+    {'name': 'polygon', 'class': 'polygon' , 'kwargs': {}, 'expected': '\n\npolygon(points = [[0, 0], [1, 0], [0, 1]]);', 'args': {'points': [[0, 0, 0], [1, 0, 0], [0, 1, 0]]}, },
     {'name': 'circle', 'class': 'circle' , 'kwargs': {'segments': 12, 'r': 1}, 'expected': '\n\ncircle($fn = 12, r = 1);', 'args': {}, },
     {'name': 'circle_diam', 'class': 'circle' , 'kwargs': {'segments': 12, 'd': 1}, 'expected': '\n\ncircle($fn = 12, d = 1);', 'args': {}, },
     {'name': 'square', 'class': 'square' , 'kwargs': {'center': False, 'size': 1}, 'expected': '\n\nsquare(center = false, size = 1);', 'args': {}, },
@@ -40,6 +41,7 @@ scad_test_case_templates = [
     {'name': 'offset', 'class': 'offset' , 'kwargs': {'r': 1}, 'expected': '\n\noffset(r = 1);', 'args': {}, },
     {'name': 'offset_segments', 'class': 'offset' , 'kwargs': {'r': 1, 'segments': 12}, 'expected': '\n\noffset($fn = 12, r = 1);', 'args': {}, },
     {'name': 'offset_chamfer', 'class': 'offset' , 'kwargs': {'delta': 1}, 'expected': '\n\noffset(chamfer = false, delta = 1);', 'args': {}, },
+    {'name': 'offset_zero_delta', 'class': 'offset' , 'kwargs': {'r': 0}, 'expected': '\n\noffset(r = 0);', 'args': {}, },
     {'name': 'hull', 'class': 'hull' , 'kwargs': {}, 'expected': '\n\nhull();', 'args': {}, },
     {'name': 'render', 'class': 'render' , 'kwargs': {'convexity': None}, 'expected': '\n\nrender();', 'args': {}, },
     {'name': 'projection', 'class': 'projection' , 'kwargs': {'cut': None}, 'expected': '\n\nprojection();', 'args': {}, },
@@ -204,6 +206,30 @@ class TestSolidPython(DiffOutput):
         expected = f"{header}\nuse <{abs_path}>\n\n\nsteps(howmany = 3);"
         self.assertEqual(expected, actual)
 
+        # Make sure we throw ValueError on nonexistent imports
+        self.assertRaises(ValueError, import_scad, 'path/doesnt/exist.scad')
+
+        # Test that we recursively import directories correctly
+        examples = import_scad(include_file.parent)
+        self.assertTrue(hasattr(examples, 'scad_to_include'))
+        self.assertTrue(hasattr(examples.scad_to_include, 'steps'))
+
+        # TODO: we should test that:
+        # A) scad files in the designated OpenSCAD library directories 
+        #       (path-dependent, see: solid.objects._openscad_library_paths()) 
+        #       are imported correctly. Not sure how to do this without writing
+        #       temp files to those directories. Seems like overkill for the moment
+        
+    def test_imported_scad_arguments(self):
+        include_file = self.expand_scad_path("examples/scad_to_include.scad")
+        mod = import_scad(include_file)
+        points = mod.scad_points();
+        poly = polygon(points);
+        actual = scad_render(poly);
+        abs_path = points._get_include_path(include_file)
+        expected = f'use <{abs_path}>\n\n\npolygon(points = scad_points());'
+        self.assertEqual(expected, actual)
+        
     def test_use_reserved_words(self):
         scad_str = '''module reserved_word_arg(or=3){\n\tcube(or);\n}\nmodule or(arg=3){\n\tcube(arg);\n}\n'''
 
